import unittest

from sparclur.parsers import XPDF
from test.parser_tests import ParserTestMixin, TracerTestMixin, RendererTestMixin, TextExtractorTestMixin, \
    FontExtractorTestMixin, TEST_PDF


class XPDFTestCase(unittest.TestCase, ParserTestMixin, TracerTestMixin, RendererTestMixin, TextExtractorTestMixin,
                   FontExtractorTestMixin):

    def setUp(self):
        self.parser = XPDF
        self.parser_instance = XPDF(TEST_PDF)


if __name__ == '__main__':
    unittest.main()



import unittest

from sparclur.parsers import QPDF
from test.parser_tests import ParserTestMixin, TracerTestMixin, MetadataExtractorTestMixin, TEST_PDF


class QPDFTestCase(unittest.TestCase, ParserTestMixin, TracerTestMixin, MetadataExtractorTestMixin):

    def setUp(self):
        self.parser = QPDF
        self.parser_instance = QPDF(TEST_PDF)


if __name__ == '__main__':
    unittest.main()



import unittest
from sparclur.parsers import PDFium
from parser_tests import ParserTestMixin, RendererTestMixin, TEST_PDF


class PDFiumTestCase(unittest.TestCase, ParserTestMixin, RendererTestMixin):

    def setUp(self):
        self.parser = PDFium
        self.parser_instance = PDFium(TEST_PDF)


if __name__ == '__main__':
    unittest.main()



import unittest

from sparclur.parsers import PDFCPU
from test.parser_tests import ParserTestMixin, TracerTestMixin, TEST_PDF


class PDFCPUTestCase(unittest.TestCase, ParserTestMixin, TracerTestMixin):

    def setUp(self):
        self.parser = PDFCPU
        self.parser_instance = PDFCPU(TEST_PDF)


if __name__ == '__main__':
    unittest.main()



import unittest

from sparclur.parsers import Poppler
from test.parser_tests import ParserTestMixin, TracerTestMixin, RendererTestMixin, TextExtractorTestMixin, \
    FontExtractorTestMixin, ImageDataExtractorTestMixin, ReforgerTestMixin, TEST_PDF


class PopplerTestCase(unittest.TestCase, ParserTestMixin, TracerTestMixin, RendererTestMixin, TextExtractorTestMixin,
                      FontExtractorTestMixin, ImageDataExtractorTestMixin, ReforgerTestMixin):

    def setUp(self):
        self.parser = Poppler
        self.parser_instance = Poppler(TEST_PDF)


if __name__ == '__main__':
    unittest.main()



import unittest

from parser_tests import ParserTestMixin, TracerTestMixin, RendererTestMixin, TextExtractorTestMixin, TEST_PDF, \
    ReforgerTestMixin
from sparclur.parsers import MuPDF


class MuPDFTestCase(unittest.TestCase, ParserTestMixin, TracerTestMixin, RendererTestMixin, TextExtractorTestMixin,
                    ReforgerTestMixin):

    def setUp(self):
        self.parser = MuPDF
        self.parser_instance = MuPDF(TEST_PDF)
        

if __name__ == '__main__':
    unittest.main()



import setuptools

from setuptools import setup
import pathlib

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

setup(
    name="sparclur",
    version="2022.03.00",
    author="Shawn Davis",
    author_email="shawn@levelupresearch.com",
    description="Tools for analyzing PDF files and compare PDF parsers",
    long_description=README,
    long_description_content_type="text/markdown",
    url="https://github.com/levelupresearch/sparclur",
    packages=setuptools.find_packages('sparclur', 'sparclur.*'),
    python_requires='>=3.8',
    license='Apache-2.0',
    install_requires=[
        'pandas',
        'func-timeout',
        'numpy',
        'scikit-image',
        'scikit-learn',
        'Pebble',
        'tqdm',
        'PyMuPDF',
        'Pillow',
        'matplotlib',
        'Pillow',
        'pytesseract',
        'spacy',
        'dill',
        'pdfminer.six',
        'pypdfium2',
        'opencv-python',
        'ImageHash',
        'PyYAML',
        'mmh3',
        'seaborn',
        'plotly',
        'docstring-inheritance'
    ]
)



import unittest
from sparclur.parsers import Arlington
from parser_tests import ParserTestMixin, TracerTestMixin, TEST_PDF


class ArlingtonTestCase(unittest.TestCase, ParserTestMixin, TracerTestMixin):

    def setUp(self):
        self.parser = Arlington
        self.parser_instance = Arlington(TEST_PDF)


if __name__ == '__main__':
    unittest.main()



import unittest
from sparclur.parsers import Ghostscript
from parser_tests import ParserTestMixin, RendererTestMixin, ReforgerTestMixin, TEST_PDF


class GhostscriptTestCase(unittest.TestCase, ParserTestMixin, RendererTestMixin, ReforgerTestMixin):

    def setUp(self):
        self.parser = Ghostscript
        self.parser_instance = Ghostscript(TEST_PDF)


if __name__ == '__main__':
    unittest.main()



import unittest
from sparclur.parsers import PDFMiner
from parser_tests import ParserTestMixin, TextExtractorTestMixin, MetadataExtractorTestMixin, TEST_PDF


class PDFMinerTestCase(unittest.TestCase, ParserTestMixin, TextExtractorTestMixin, MetadataExtractorTestMixin):

    def setUp(self):
        self.parser = PDFMiner
        self.parser_instance = PDFMiner(TEST_PDF)


if __name__ == '__main__':
    unittest.main()
